==> 1.2025.316.6.tar.gz: OBJECTS/gen/ui/webui/resources/tsc/cr_components/composebox/composebox_match.d.ts <==
import '//resources/cr_elements/cr_icon_button/cr_icon_button.js';
import { CrLitElement } from '//resources/lit/v3_0/lit.rollup.js';
import type { AutocompleteMatch } from '//resources/mojo/components/omnibox/browser/searchbox.mojom-webui.js';
export interface ComposeboxMatchElement {
    $: {
        remove: HTMLElement;
    };
}
export declare class ComposeboxMatchElement extends CrLitElement {
    static get is(): string;
    static get styles(): import("//resources/lit/v3_0/lit.rollup.js").CSSResultGroup;
    render(): import("//resources/lit/v3_0/lit.rollup.js").TemplateResult<1>;
    static get properties(): {
        match: {
            type: ObjectConstructor;
        };
        /**
         * Index of the match in the autocomplete result. Used to inform embedder
         * of events such as deletion, click, etc.
         */
        matchIndex: {
            type: NumberConstructor;
        };
        removeButtonTitle_: {
            type: StringConstructor;
        };
    };
    accessor match: AutocompleteMatch;
    accessor matchIndex: number;
    private searchboxHandler_;
    protected accessor removeButtonTitle_: string;
    constructor();
    connectedCallback(): void;
    protected computeContents_(): string;
    protected computeRemoveButtonAriaLabel_(): string;
    protected iconPath_(): string;
    private onMatchFocusin_;
    private onMatchClick_;
    protected onRemoveButtonClick_(e: MouseEvent): void;
    protected onRemoveButtonMouseDown_(e: Event): void;
}
declare global {
    interface HTMLElementTagNameMap {
        'ntp-composebox-match': ComposeboxMatchElement;
    }
}

==> 1.2025.337.4.tar.gz: OBJECTS/gen/ui/webui/resources/tsc/cr_components/composebox/composebox_match.d.ts <==
import '//resources/cr_elements/cr_icon_button/cr_icon_button.js';
import { CrLitElement } from '//resources/lit/v3_0/lit.rollup.js';
import type { AutocompleteMatch } from '//resources/mojo/components/omnibox/browser/searchbox.mojom-webui.js';
export interface ComposeboxMatchElement {
    $: {
        remove: HTMLElement;
    };
}
export declare class ComposeboxMatchElement extends CrLitElement {
    static get is(): string;
    static get styles(): import("//resources/lit/v3_0/lit.rollup.js").CSSResultGroup;
    render(): import("//resources/lit/v3_0/lit.rollup.js").TemplateResult<1>;
    static get properties(): {
        match: {
            type: ObjectConstructor;
        };
        /**
         * Index of the match in the autocomplete result. Used to inform embedder
         * of events such as deletion, click, etc.
         */
        matchIndex: {
            type: NumberConstructor;
        };
        removeButtonTitle_: {
            type: StringConstructor;
        };
    };
    accessor match: AutocompleteMatch;
    accessor matchIndex: number;
    private searchboxHandler_;
    protected accessor removeButtonTitle_: string;
    constructor();
    connectedCallback(): void;
    protected computeContents_(): string;
    protected computeRemoveButtonAriaLabel_(): string;
    protected iconPath_(): string;
    private onMatchFocusin_;
    private onMouseDown_;
    protected onRemoveButtonClick_(e: MouseEvent): void;
    protected onRemoveButtonMouseDown_(e: Event): void;
}
declare global {
    interface HTMLElementTagNameMap {
        'cr-composebox-match': ComposeboxMatchElement;
    }
}
